pub enum Output {
File(FileOutput),
Store(PathBuf),
FileAndStore {
file: FileOutput,
store_directory: PathBuf,
},
}Expand description
Defines how the final symbols are outputted
Variants
File(FileOutput)
Store(PathBuf)
Store output symbols as FILENAME.<ext>/DEBUG_ID/FILENAME.sym in the specified directory, ie the symbol store format
FileAndStore
Writes symbols to a file as well as storing them in the symbol store format to the specified directory